Struct ITIP20ChannelReserveInstance
pub struct ITIP20ChannelReserveInstance<P, N = Ethereum> {
address: Address,
provider: P,
_network: PhantomData<N>,
}Expand description
A ITIP20ChannelReserve instance.
Contains type-safe methods for interacting with an on-chain instance of the
ITIP20ChannelReserve contract located at a given address, using a given
provider P.
If the contract bytecode is available (see the sol!
documentation on how to provide it), the deploy and deploy_builder methods can
be used to deploy a new instance of the contract.
See the module-level documentation for all the available methods.
Fields
address: Addressprovider: P_network: PhantomData<N>Implementations
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Instantiation and getters/setters.
pub const fn new(
address: Address,
__provider: P,
) -> ITIP20ChannelReserveInstance<P, N>
pub const fn new( address: Address, __provider: P, ) -> ITIP20ChannelReserveInstance<P, N>
Creates a new wrapper around an on-chain ITIP20ChannelReserve contract instance.
See the wrapper’s documentation for more details.
pub fn set_address(&mut self, address: Address)
pub fn set_address(&mut self, address: Address)
Sets the address.
pub fn at(self, address: Address) -> ITIP20ChannelReserveInstance<P, N>
pub fn at(self, address: Address) -> ITIP20ChannelReserveInstance<P, N>
Sets the address and returns self.
impl<P, N> ITIP20ChannelReserveInstance<&P, N>where
P: Clone,
impl<P, N> ITIP20ChannelReserveInstance<&P, N>where
P: Clone,
pub fn with_cloned_provider(self) -> ITIP20ChannelReserveInstance<P, N>
pub fn with_cloned_provider(self) -> ITIP20ChannelReserveInstance<P, N>
Clones the provider and returns a new instance with the cloned provider.
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Function calls.
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
pub fn call_builder<C>(&self, call: &C) -> CallBuilder<&P, PhantomData<C>, N>where
C: SolCall,
Creates a new call builder using this contract instance’s provider and address.
Note that the call can be any function call, not just those defined in this contract. Prefer using the other methods for building type-safe contract calls.
pub fn CLOSE_GRACE_PERIOD(
&self,
) -> CallBuilder<&P, PhantomData<CLOSE_GRACE_PERIODCall>, N>
pub fn CLOSE_GRACE_PERIOD( &self, ) -> CallBuilder<&P, PhantomData<CLOSE_GRACE_PERIODCall>, N>
Creates a new call builder for the [CLOSE_GRACE_PERIOD] function.
pub fn VOUCHER_TYPEHASH(
&self,
) -> CallBuilder<&P, PhantomData<VOUCHER_TYPEHASHCall>, N>
pub fn VOUCHER_TYPEHASH( &self, ) -> CallBuilder<&P, PhantomData<VOUCHER_TYPEHASHCall>, N>
Creates a new call builder for the [VOUCHER_TYPEHASH] function.
pub fn open(
&self,
payee: Address,
operator: Address,
token: Address,
deposit: Uint<96, 2>,
salt: FixedBytes<32>,
authorizedSigner: Address,
) -> CallBuilder<&P, PhantomData<openCall>, N>
pub fn open( &self, payee: Address, operator: Address, token: Address, deposit: Uint<96, 2>, salt: FixedBytes<32>, authorizedSigner: Address, ) -> CallBuilder<&P, PhantomData<openCall>, N>
Creates a new call builder for the [open] function.
pub fn settle(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
cumulativeAmount: Uint<96, 2>,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<settleCall>, N>
pub fn settle( &self, descriptor: <ChannelDescriptor as SolType>::RustType, cumulativeAmount: Uint<96, 2>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<settleCall>, N>
Creates a new call builder for the [settle] function.
pub fn topUp(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
additionalDeposit: Uint<96, 2>,
) -> CallBuilder<&P, PhantomData<topUpCall>, N>
pub fn topUp( &self, descriptor: <ChannelDescriptor as SolType>::RustType, additionalDeposit: Uint<96, 2>, ) -> CallBuilder<&P, PhantomData<topUpCall>, N>
Creates a new call builder for the [topUp] function.
pub fn close(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
cumulativeAmount: Uint<96, 2>,
captureAmount: Uint<96, 2>,
signature: Bytes,
) -> CallBuilder<&P, PhantomData<closeCall>, N>
pub fn close( &self, descriptor: <ChannelDescriptor as SolType>::RustType, cumulativeAmount: Uint<96, 2>, captureAmount: Uint<96, 2>, signature: Bytes, ) -> CallBuilder<&P, PhantomData<closeCall>, N>
Creates a new call builder for the [close] function.
pub fn requestClose(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<requestCloseCall>, N>
pub fn requestClose( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<requestCloseCall>, N>
Creates a new call builder for the [requestClose] function.
pub fn withdraw(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<withdrawCall>, N>
pub fn withdraw( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<withdrawCall>, N>
Creates a new call builder for the [withdraw] function.
pub fn getChannel(
&self,
descriptor: <ChannelDescriptor as SolType>::RustType,
) -> CallBuilder<&P, PhantomData<getChannelCall>, N>
pub fn getChannel( &self, descriptor: <ChannelDescriptor as SolType>::RustType, ) -> CallBuilder<&P, PhantomData<getChannelCall>, N>
Creates a new call builder for the [getChannel] function.
pub fn getChannelState(
&self,
channelId: FixedBytes<32>,
) -> CallBuilder<&P, PhantomData<getChannelStateCall>, N>
pub fn getChannelState( &self, channelId: FixedBytes<32>, ) -> CallBuilder<&P, PhantomData<getChannelStateCall>, N>
Creates a new call builder for the [getChannelState] function.
pub fn getChannelStatesBatch(
&self,
channelIds: Vec<FixedBytes<32>>,
) -> CallBuilder<&P, PhantomData<getChannelStatesBatchCall>, N>
pub fn getChannelStatesBatch( &self, channelIds: Vec<FixedBytes<32>>, ) -> CallBuilder<&P, PhantomData<getChannelStatesBatchCall>, N>
Creates a new call builder for the [getChannelStatesBatch] function.
pub fn computeChannelId(
&self,
payer: Address,
payee: Address,
operator: Address,
token: Address,
salt: FixedBytes<32>,
authorizedSigner: Address,
expiringNonceHash: FixedBytes<32>,
) -> CallBuilder<&P, PhantomData<computeChannelIdCall>, N>
pub fn computeChannelId( &self, payer: Address, payee: Address, operator: Address, token: Address, salt: FixedBytes<32>, authorizedSigner: Address, expiringNonceHash: FixedBytes<32>, ) -> CallBuilder<&P, PhantomData<computeChannelIdCall>, N>
Creates a new call builder for the [computeChannelId] function.
pub fn getVoucherDigest(
&self,
channelId: FixedBytes<32>,
cumulativeAmount: Uint<96, 2>,
) -> CallBuilder<&P, PhantomData<getVoucherDigestCall>, N>
pub fn getVoucherDigest( &self, channelId: FixedBytes<32>, cumulativeAmount: Uint<96, 2>, ) -> CallBuilder<&P, PhantomData<getVoucherDigestCall>, N>
Creates a new call builder for the [getVoucherDigest] function.
pub fn domainSeparator(
&self,
) -> CallBuilder<&P, PhantomData<domainSeparatorCall>, N>
pub fn domainSeparator( &self, ) -> CallBuilder<&P, PhantomData<domainSeparatorCall>, N>
Creates a new call builder for the [domainSeparator] function.
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
impl<P, N> ITIP20ChannelReserveInstance<P, N>where
P: Provider<N>,
N: Network,
Event filters.
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
pub fn event_filter<E>(&self) -> Event<&P, E, N>where
E: SolEvent,
Creates a new event filter using this contract instance’s provider and address.
Note that the type can be any event, not just those defined in this contract. Prefer using the other methods for building type-safe event filters.
pub fn ChannelOpened_filter(&self) -> Event<&P, ChannelOpened, N>
pub fn ChannelOpened_filter(&self) -> Event<&P, ChannelOpened, N>
Creates a new event filter for the ChannelOpened event.
pub fn Settled_filter(&self) -> Event<&P, Settled, N>
pub fn Settled_filter(&self) -> Event<&P, Settled, N>
Creates a new event filter for the Settled event.
pub fn TopUp_filter(&self) -> Event<&P, TopUp, N>
pub fn TopUp_filter(&self) -> Event<&P, TopUp, N>
Creates a new event filter for the TopUp event.
pub fn CloseRequested_filter(&self) -> Event<&P, CloseRequested, N>
pub fn CloseRequested_filter(&self) -> Event<&P, CloseRequested, N>
Creates a new event filter for the CloseRequested event.
pub fn ChannelClosed_filter(&self) -> Event<&P, ChannelClosed, N>
pub fn ChannelClosed_filter(&self) -> Event<&P, ChannelClosed, N>
Creates a new event filter for the ChannelClosed event.
pub fn CloseRequestCancelled_filter(
&self,
) -> Event<&P, CloseRequestCancelled, N>
pub fn CloseRequestCancelled_filter( &self, ) -> Event<&P, CloseRequestCancelled, N>
Creates a new event filter for the CloseRequestCancelled event.